The HentaiVerse

2243
101
60
115
Battle Time
Choose from the Battle Actions highlighted above, and use them to defeat your enemies listed to the right. When all enemies are reduced to zero Health, you win. If your Health reaches zero, you are defeated.

Pa115 has been defeated.
Bleeding Wound hits Pa115 for 677 damage.
The effect Overwhelming Strikes has worn off.
Regeneration restores 54 points of health.
Replenishment restores 2 points of magic.
Refreshment restores 1 points of spirit.
Regen restores 142 points of health.
Low-grade Farmer 153 glances you; you partially block the attack, and take 26 points of Piercing damage.
Pa115 glances you, causing 34 points of Crushing damage.
You crit Pa115, which partially parries, causing 1177 points of Slashing damage.
Pa115 gains the effect Bleeding Wound.
The effect Stunned on Pa115 has worn off.
Regeneration restores 54 points of health.
Replenishment restores 2 points of magic.
Refreshment restores 1 points of spirit.
Regen restores 142 points of health.
Scary Ghost hits you, causing 47 points of Void damage.
Low-grade Farmer 153 hits you; you partially block the attack, and take 49 points of Piercing damage.
Blue Slime has been defeated.
You hit Blue Slime, causing 1453 points of Slashing damage.
Regeneration restores 54 points of health.
Replenishment restores 2 points of magic.
Refreshment restores 1 points of spirit.
Regen restores 142 points of health.
Scary Ghost hits you, causing 44 points of Void damage.
Blue Slime casts Bouip, which hits! You partially block the attack, and take 107 Holy damage.
Low-grade Farmer 153 crits you; you partially block and partially parry the attack, and take 32 points of Piercing damage.
You hit Blue Slime, causing 1620 points of Slashing damage.
Sleeping Dragon has been defeated.
You counter Sleeping Dragon for 994 points of Slashing damage.
Sleeping Dragon hits you; you partially block and partially parry the attack, and take 15 points of Piercing damage.
Scary Ghost glances you; you partially block the attack, and take 12 points of Void damage.
Blue Slime hits you; you partially block the attack, and take 21 points of Crushing damage.
You glance Sleeping Dragon, causing 534 points of Slashing damage.
Regeneration restores 54 points of health.
Replenishment restores 2 points of magic.
Refreshment restores 1 points of spirit.
Regen restores 142 points of health.
Low-grade Farmer 153 crits you, causing 118 points of Piercing damage.
Sleeping Dragon glances you; you partially block the attack, and take 15 points of Piercing damage.
You hit Sleeping Dragon, causing 984 points of Slashing damage.
Regeneration restores 54 points of health.
Replenishment restores 2 points of magic.
Refreshment restores 1 points of spirit.
Regen restores 142 points of health.
Scary Ghost hits you, causing 42 points of Void damage.
Blue Slime glances you; you partially block the attack, and take 11 points of Crushing damage.
Low-grade Farmer 153 hits you, causing 91 points of Piercing damage.
Sleeping Dragon uses Nightmare, which hits! You take 209 Piercing damage.
Pa115 gains the effect Stunned.
You counter Pa115 for 1329 points of Slashing damage.
Pa115 hits you; you partially block the attack, and take 34 points of Crushing damage.
You gain the effect Overwhelming Strikes.
Saw World New New has been defeated.
You hit Saw World New New, causing 1333 points of Slashing damage.
You parry the attack from Saw World New New.
Scary Ghost hits you, causing 47 points of Void damage.
Blue Slime hits you, causing 46 points of Crushing damage.
Low-grade Farmer 153 hits you, causing 92 points of Piercing damage.
You 2x-crit Saw World New New, causing 2580 points of Slashing damage.
Saw World New New gains the effect Bleeding Wound.
Spawned Monster F: MID=346406 (Low-grade Farmer 153) LV=85 HP=2094
Spawned Monster E: MID=7 (Scary Ghost) LV=85 HP=2227
Spawned Monster D: MID=297311 (Pa115) LV=85 HP=2714
Spawned Monster C: MID=10 (Blue Slime) LV=85 HP=1932
Spawned Monster B: MID=368817 (Sleeping Dragon) LV=85 HP=2444
Spawned Monster A: MID=324808 (Saw World New New) LV=85 HP=3155
Initializing Grindfest (Round 12 / 1000) ...